import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PodSecurityPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#metadata PodSecurityPolicy#metadata}
     *
     * @stability stable
     */
    readonly metadata: PodSecurityPolicyMetadata[];
    /**
     * spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#spec PodSecurityPolicy#spec}
     *
     * @stability stable
     */
    readonly spec: PodSecurityPolicySpec[];
}
/**
 * @stability stable
 */
export interface PodSecurityPolicyMetadata {
    /**
     * An unstructured key value map stored with the podsecuritypolicy that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#annotations PodSecurityPolicy#annotations}
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the podsecuritypolicy.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#labels PodSecurityPolicy#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the podsecuritypolicy, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#name PodSecurityPolicy#name}
     *
     * @stability stable
     */
    readonly name?: string;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecAllowedFlexVolumes {
    /**
     * driver is the name of the Flexvolume driver.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#driver PodSecurityPolicy#driver}
     *
     * @stability stable
     */
    readonly driver: string;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecAllowedHostPaths {
    /**
     * pathPrefix is the path prefix that the host volume must match.
     *
     * It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
     *
     * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#path_prefix PodSecurityPolicy#path_prefix}
     *
     * @stability stable
     */
    readonly pathPrefix: string;
    /**
     * when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#read_only PodSecurityPolicy#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecFsGroupRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecFsGroup {
    /**
     * rule is the strategy that will dictate what FSGroup is used in the SecurityContext.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecFsGroupRange[];
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecHostPorts {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsGroupRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsGroup {
    /**
     * rule is the strategy that will dictate the allowable RunAsGroup values that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecRunAsGroupRange[];
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsUserRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecRunAsUser {
    /**
     * rule is the strategy that will dictate the allowable RunAsUser values that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecRunAsUserRange[];
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSeLinuxSeLinuxOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#level PodSecurityPolicy#level}.
     *
     * @stability stable
     */
    readonly level: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#role PodSecurityPolicy#role}.
     *
     * @stability stable
     */
    readonly role: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#type PodSecurityPolicy#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#user PodSecurityPolicy#user}.
     *
     * @stability stable
     */
    readonly user: string;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSeLinux {
    /**
     * rule is the strategy that will dictate the allowable labels that may be set.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * se_linux_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#se_linux_options PodSecurityPolicy#se_linux_options}
     *
     * @stability stable
     */
    readonly seLinuxOptions?: PodSecurityPolicySpecSeLinuxSeLinuxOptions[];
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSupplementalGroupsRange {
    /**
     * max is the end of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#max PodSecurityPolicy#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * min is the start of the range, inclusive.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#min PodSecurityPolicy#min}
     *
     * @stability stable
     */
    readonly min: number;
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpecSupplementalGroups {
    /**
     * rule is the strategy that will dictate what supplemental groups is used in the SecurityContext.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#rule PodSecurityPolicy#rule}
     *
     * @stability stable
     */
    readonly rule: string;
    /**
     * range block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#range PodSecurityPolicy#range}
     *
     * @stability stable
     */
    readonly range?: PodSecurityPolicySpecSupplementalGroupsRange[];
}
/**
 * @stability stable
 */
export interface PodSecurityPolicySpec {
    /**
     * allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allow_privilege_escalation PodSecurityPolicy#allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly allowPrivilegeEscalation?: boolean;
    /**
     * allowedCapabilities is a list of capabilities that can be requested to add to the container.
     *
     * Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_capabilities PodSecurityPolicy#allowed_capabilities}
     *
     * @stability stable
     */
    readonly allowedCapabilities?: string[];
    /**
     * AllowedProcMountTypes is an allowlist of allowed ProcMountTypes.
     *
     * Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_proc_mount_types PodSecurityPolicy#allowed_proc_mount_types}
     *
     * @stability stable
     */
    readonly allowedProcMountTypes?: string[];
    /**
     * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none.
     *
     * Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to allowlist all allowed unsafe sysctls explicitly to avoid rejection.
     *
     * Examples: e.g. "foo/*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_unsafe_sysctls PodSecurityPolicy#allowed_unsafe_sysctls}
     *
     * @stability stable
     */
    readonly allowedUnsafeSysctls?: string[];
    /**
     * defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.
     *
     * You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#default_add_capabilities PodSecurityPolicy#default_add_capabilities}
     *
     * @stability stable
     */
    readonly defaultAddCapabilities?: string[];
    /**
     * defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#default_allow_privilege_escalation PodSecurityPolicy#default_allow_privilege_escalation}
     *
     * @stability stable
     */
    readonly defaultAllowPrivilegeEscalation?: boolean;
    /**
     * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none.
     *
     * Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
     *
     * Examples: e.g. "foo/*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#forbidden_sysctls PodSecurityPolicy#forbidden_sysctls}
     *
     * @stability stable
     */
    readonly forbiddenSysctls?: string[];
    /**
     * hostIPC determines if the policy allows the use of HostIPC in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_ipc PodSecurityPolicy#host_ipc}
     *
     * @stability stable
     */
    readonly hostIpc?: boolean;
    /**
     * hostNetwork determines if the policy allows the use of HostNetwork in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_network PodSecurityPolicy#host_network}
     *
     * @stability stable
     */
    readonly hostNetwork?: boolean;
    /**
     * hostPID determines if the policy allows the use of HostPID in the pod spec.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_pid PodSecurityPolicy#host_pid}
     *
     * @stability stable
     */
    readonly hostPid?: boolean;
    /**
     * privileged determines if a pod can request to be run as privileged.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#privileged PodSecurityPolicy#privileged}
     *
     * @stability stable
     */
    readonly privileged?: boolean;
    /**
     * readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.
     *
     * If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#read_only_root_filesystem PodSecurityPolicy#read_only_root_filesystem}
     *
     * @stability stable
     */
    readonly readOnlyRootFilesystem?: boolean;
    /**
     * requiredDropCapabilities are the capabilities that will be dropped from the container.
     *
     * These are required to be dropped and cannot be added.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#required_drop_capabilities PodSecurityPolicy#required_drop_capabilities}
     *
     * @stability stable
     */
    readonly requiredDropCapabilities?: string[];
    /**
     * volumes is an allowlist of volume plugins.
     *
     * Empty indicates that no volumes may be used. To allow all volumes you may use '*'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#volumes PodSecurityPolicy#volumes}
     *
     * @stability stable
     */
    readonly volumes?: string[];
    /**
     * allowed_flex_volumes block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_flex_volumes PodSecurityPolicy#allowed_flex_volumes}
     *
     * @stability stable
     */
    readonly allowedFlexVolumes?: PodSecurityPolicySpecAllowedFlexVolumes[];
    /**
     * allowed_host_paths block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#allowed_host_paths PodSecurityPolicy#allowed_host_paths}
     *
     * @stability stable
     */
    readonly allowedHostPaths?: PodSecurityPolicySpecAllowedHostPaths[];
    /**
     * fs_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#fs_group PodSecurityPolicy#fs_group}
     *
     * @stability stable
     */
    readonly fsGroup: PodSecurityPolicySpecFsGroup[];
    /**
     * host_ports block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#host_ports PodSecurityPolicy#host_ports}
     *
     * @stability stable
     */
    readonly hostPorts?: PodSecurityPolicySpecHostPorts[];
    /**
     * run_as_group block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#run_as_group PodSecurityPolicy#run_as_group}
     *
     * @stability stable
     */
    readonly runAsGroup?: PodSecurityPolicySpecRunAsGroup[];
    /**
     * run_as_user block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#run_as_user PodSecurityPolicy#run_as_user}
     *
     * @stability stable
     */
    readonly runAsUser: PodSecurityPolicySpecRunAsUser[];
    /**
     * se_linux block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#se_linux PodSecurityPolicy#se_linux}
     *
     * @stability stable
     */
    readonly seLinux?: PodSecurityPolicySpecSeLinux[];
    /**
     * supplemental_groups block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html#supplemental_groups PodSecurityPolicy#supplemental_groups}
     *
     * @stability stable
     */
    readonly supplementalGroups: PodSecurityPolicySpecSupplementalGroups[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html kubernetes_pod_security_policy}.
 *
 * @stability stable
 */
export declare class PodSecurityPolicy extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/r/pod_security_policy.html kubernetes_pod_security_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PodSecurityPolicyConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _metadata;
    /**
     * @stability stable
     */
    get metadata(): PodSecurityPolicyMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: PodSecurityPolicyMetadata[]);
    /**
     * @stability stable
     */
    get metadataInput(): PodSecurityPolicyMetadata[];
    private _spec;
    /**
     * @stability stable
     */
    get spec(): PodSecurityPolicySpec[];
    /**
     * @stability stable
     */
    set spec(value: PodSecurityPolicySpec[]);
    /**
     * @stability stable
     */
    get specInput(): PodSecurityPolicySpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
